/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.editingsupport;

import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.TableViewer;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;
import org.fortiss.tooling.base.ui.annotation.AnnotationEntry;

/**
 * 
 * @author diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: 065B49AEE88451C179F62E2D2A3D7D15
 */
public class CheckBoxEditingSupport extends AnnotationEditingSupportBase {

	/** Contains the {@link BooleanCellEditor} that is displayed. */
	protected BooleanCellEditor checkBoxEditor = null;

	/** Flag if this {@link BooleanCellEditor} is editable. */
	boolean isEditable;

	/** References the column viewer. */
	ColumnViewer viewer;

	/** Constructor. */
	public CheckBoxEditingSupport(ColumnViewer viewer,
			Class<? extends IAnnotatedSpecification> specClass, String instanceKey) {
		super(viewer, specClass, instanceKey);
		this.viewer = viewer;
		checkBoxEditor = new BooleanCellEditor(((TableViewer)viewer).getTable());
	}

	/** {@inheritDoc} */
	@Override
	protected CellEditor getCellEditor(Object element) {
		if(!(element instanceof AnnotationEntry)) {
			return null;
		}

		return checkBoxEditor;
	}

	/** {@inheritDoc} */
	@Override
	protected void setValue(Object element, Object box) {
		if(isEditable) {
			super.setValue(element, checkBoxEditor.getValue());
		}
	}

	/** {@inheritDoc} */
	@Override
	protected Object getValue(Object element) {
		Object value = super.getValue(element);

		if(value != null) {
			isEditable = ((AnnotationEntry)element).canEdit(specClass);
			checkBoxEditor.setValue(value);
		}

		return value;
	}

}
